\name{predict.rvbm}
\alias{predict.rvbm}
\title{Predict Method for Variational Bayesian Multiclass Probit Regression}
\description{
  The \code{predict.rvbm} method predicts class
  membership of given test data based on 
  the Gaussian process model created by \code{rvbm}.
}
\usage{
\method{predict}{rvbm}(object, X.TEST=NULL, ...)
}
\arguments{
  \item{object}{An S3 object that inherits from the class \code{rvbm}.}
  \item{X.TEST}{A matrix of new test data. If NULL, the feature matrix in obj is used instead.}
  \item{\dots}{Not used.}
}
\value{
    An vector containing the predicted class membership based on the maximum posterior probability.
    An attribute named \code{Ptest} contains the predicted posterior probability.
}
\author{
  Chi Yau\cr
  \email{chi.yau@r-tutor.com}
}
\note{
  This replaces the \code{predictCPP} and \code{predClass} methods in \code{vbmp}.
}
\seealso{\code{\link{rvbm}}, \code{vbmp}}

\examples{
\dontrun{
library(rpud)

x <- rvbm.sample.train$X
y <- rvbm.sample.train$t.class
model.rvbm <- rvbm( 
    x, y, x, y,
    theta = rep(1, ncol(x)), 
    control = list(
            sKernelType="gaussian", 
            bThetaEstimate=TRUE, 
            bMonitor=TRUE,
            InfoLevel=1) 
)

res <- predict(model.rvbm, rvbm.test$X)
err <- sum(res != rvbm.test$t.class); err
rate <- err/length(rvbm.test$t.class)*100; rate
}}
\keyword{neural}
\keyword{nonlinear}
\keyword{classif}

